@@ -6,7 +6,8 @@ package CljPerl::Atom;
   use CljPerl::Printer;
   use CljPerl::Logger;
 
-  our $VERSION = '0.07';
+  our $VERSION = '0.08';
+  our $id = 0;
   
   sub new {
     my $class = shift;
@@ -16,6 +17,7 @@ package CljPerl::Atom;
     my $self = {class=>"Atom",
 	        type=>$type,
 	        value=>$value,
+                object_id=>"atom" . ($id++), 
                 meta=>undef,
 	        pos=>{filename=>"unknown",
 		      line=>0,
@@ -39,6 +41,11 @@ package CljPerl::Atom;
     }
   }
 
+  sub object_id {
+    my $self = shift;
+    return $self->{object_id}; 
+  }
+
   sub meta {
     my $self = shift;
     my $meta = shift;
